@@ -3,7 +3,7 @@ package Test::Nginx::Util;
 use strict;
 use warnings;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use base 'Exporter';
 
@@ -12,7 +12,6 @@ use File::Spec ();
 use HTTP::Response;
 use Module::Install::Can;
 use Cwd qw( cwd );
-use Module::Install::Can;
 use List::Util qw( shuffle );
 
 our $NoNginxManager = 0;
@@ -62,9 +61,9 @@ our @EXPORT_OK = qw(
 );
 
 our $Workers                = 1;
-our $WorkerConnections      = 1024;
+our $WorkerConnections      = 64;
 our $LogLevel               = 'debug';
-our $MasterProcessEnabled   = 'on';
+our $MasterProcessEnabled   = 'off';
 our $DaemonEnabled          = 'on';
 our $ServerPort             = 1984;
 our $ServerPortForClient    = 1984;
@@ -130,12 +129,31 @@ sub setup_server_root () {
         die "Failed to do mkdir $LogDir\n";
     mkdir $HtmlDir or
         die "Failed to do mkdir $HtmlDir\n";
+
+    my $index_file = "$HtmlDir/index.html";
+
+    open my $out, ">$index_file" or
+        die "Can't open $index_file for writing: $!\n";
+
+    print $out '<html><head><title>It works!</title></head><body>It works!</body></html>';
+
+    close $out;
+
     mkdir $ConfDir or
         die "Failed to do mkdir $ConfDir\n";
 }
 
-sub write_config_file ($) {
-    my $rconfig = shift;
+sub write_config_file ($$) {
+    my ($config, $http_config) = @_;
+
+    if (!defined $config) {
+        $config = '';
+    }
+
+    if (!defined $http_config) {
+        $http_config = '';
+    }
+
     open my $out, ">$ConfFile" or
         die "Can't open $ConfFile for writing: $!\n";
     print $out <<_EOC_;
@@ -150,6 +168,9 @@ http {
 
     default_type text/plain;
     keepalive_timeout  68;
+
+    $http_config
+
     server {
         listen          $ServerPort;
         server_name     localhost;
@@ -162,7 +183,7 @@ $ConfigPreamble
         # End preamble config...
 
         # Begin test case config...
-$$rconfig
+$config
         # End test case config.
 
         location / {
@@ -307,7 +328,7 @@ sub run_test ($) {
             my $pid = get_pid_from_pidfile($name);
             if (system("ps $pid > /dev/null") == 0) {
                 #warn "found running nginx...";
-                write_config_file(\$config);
+                write_config_file($config, $block->http_config);
                 if (kill(SIGQUIT, $pid) == 0) { # send quit signal
                     #warn("$name - Failed to send quit signal to the nginx process with PID $pid");
                 }
@@ -332,7 +353,7 @@ sub run_test ($) {
 
             #warn "*** Restarting the nginx server...\n";
             setup_server_root();
-            write_config_file(\$config);
+            write_config_file($config, $block->http_config);
             if ( ! Module::Install::Can->can_run('nginx') ) {
                 Test::More::BAIL_OUT("$name - Cannot find the nginx executable in the PATH environment");
                 die;
@@ -392,7 +413,7 @@ sub run_test ($) {
         if (-f $PidFile) {
             my $pid = get_pid_from_pidfile($name);
             if (system("ps $pid > /dev/null") == 0) {
-                write_config_file(\$config);
+                write_config_file($config, $block->http_config);
                 if (kill(SIGQUIT, $pid) == 0) { # send quit signal
                     #warn("$name - Failed to send quit signal to the nginx process with PID $pid");
                 }
